@@ -8,12 +8,12 @@
  **
  **   Copyright (c):  2001      by Heiner Lamprecht,
  **                   2002      by André Somers
- **                   2008-2010 by Axel Pauli
+ **                   2008-2011 by Axel Pauli
  **
  **   This file is distributed under the terms of the General Public
  **   License. See the file COPYING for more information.
  **
- **   $Id: mapconfig.cpp 4297 2010-10-05 19:11:39Z axel $
+ **   $Id: mapconfig.cpp 4533 2011-01-26 20:25:13Z axel $
  **
  ***********************************************************************/
 
@@ -78,7 +78,7 @@ MapConfig::MapConfig(QObject* parent) :
                                     BaseMapElement::CivHeliport,
                                     BaseMapElement::MilHeliport,
                                     BaseMapElement::AmbHeliport,
-                                    BaseMapElement::Glidersite,
+                                    BaseMapElement::Gliderfield,
                                     BaseMapElement::UltraLight,
                                     BaseMapElement::HangGlider,
                                     BaseMapElement::Outlanding
@@ -423,6 +423,7 @@ const QPen& MapConfig::__getPen(unsigned int typeID, int sIndex)
     case BaseMapElement::ControlD:
       return ctrDPenList[sIndex];
     case BaseMapElement::Danger:
+    case BaseMapElement::Prohibited:
       return dangerPenList[sIndex];
     case BaseMapElement::LowFlight:
       return lowFPenList[sIndex];
@@ -489,6 +490,7 @@ bool MapConfig::isBorder(unsigned int typeID)
     case BaseMapElement::ControlD:
       return ctrDBorder[scaleIndex];
     case BaseMapElement::Danger:
+    case BaseMapElement::Prohibited:
       return dangerBorder[scaleIndex];
     case BaseMapElement::LowFlight:
       return lowFBorder[scaleIndex];
@@ -547,6 +549,7 @@ const QBrush& MapConfig::__getBrush(unsigned int typeID, int sIndex)
     case BaseMapElement::ControlD:
       return ctrDBrushList[sIndex];
     case BaseMapElement::Danger:
+    case BaseMapElement::Prohibited:
       return dangerBrushList[sIndex];
     case BaseMapElement::LowFlight:
       return lowFBrushList[sIndex];
@@ -572,49 +575,49 @@ const QBrush& MapConfig::__getBrush(unsigned int typeID, int sIndex)
 
 QPixmap MapConfig::getPixmapRotatable(unsigned int typeID, bool isWinch)
 {
-  QString iconName(getPixmapName(typeID, isWinch, true));
+  QString iconName( getPixmapName( typeID, isWinch, true ) );
 
   // qDebug("PixmapNameRot: %d %s",typeID, iconName.latin1() );
 
-  if (isSwitch)
+  if( isSwitch )
     {
-      return GeneralConfig::instance()->loadPixmap(iconName);
+      return GeneralConfig::instance()->loadPixmap( iconName );
     }
   else
     {
-      return GeneralConfig::instance()->loadPixmap("small/" + iconName);
+      return GeneralConfig::instance()->loadPixmap( "small/" + iconName );
     }
 }
 
 QPixmap MapConfig::getPixmap(unsigned int typeID, bool isWinch, bool smallIcon)
 {
-  QString iconName(getPixmapName(typeID, isWinch));
+  QString iconName( getPixmapName( typeID, isWinch ) );
 
   // qDebug("getPixmapName,Winch,SmallIcon: %d %s",typeID, iconName.latin1() );
 
-  if (smallIcon)
+  if( smallIcon )
     {
-      return GeneralConfig::instance()->loadPixmap("small/" + iconName);
+      return GeneralConfig::instance()->loadPixmap( "small/" + iconName );
     }
   else
     {
-      return GeneralConfig::instance()->loadPixmap(iconName);
+      return GeneralConfig::instance()->loadPixmap( iconName );
     }
 }
 
-QPixmap MapConfig::getPixmap(unsigned int typeID, bool isWinch, QColor color)
+QPixmap MapConfig::getPixmap(unsigned int typeID, bool isWinch)
 {
-  QString iconName(getPixmapName(typeID, isWinch, false, color));
+  QString iconName( getPixmapName( typeID, isWinch, false ) );
 
   // qDebug("getPixmapName,Winch,Color: %d %s",typeID, iconName.latin1() );
 
-  if (isSwitch)
+  if( isSwitch )
     {
-      return GeneralConfig::instance()->loadPixmap(iconName);
+      return GeneralConfig::instance()->loadPixmap( iconName );
     }
   else
     {
-      return GeneralConfig::instance()->loadPixmap("small/" + iconName);
+      return GeneralConfig::instance()->loadPixmap( "small/" + iconName );
     }
 }
 
@@ -622,13 +625,13 @@ QPixmap MapConfig::getPixmap(QString iconName)
 {
   // qDebug("getPixmapName: %s", iconName.latin1() );
 
-  if (isSwitch)
+  if( isSwitch )
     {
-      return GeneralConfig::instance()->loadPixmap(iconName);
+      return GeneralConfig::instance()->loadPixmap( iconName );
     }
   else
     {
-      return GeneralConfig::instance()->loadPixmap("small/" + iconName);
+      return GeneralConfig::instance()->loadPixmap( "small/" + iconName );
     }
 }
 
@@ -640,14 +643,14 @@ bool MapConfig::isRotatable( unsigned int typeID ) const
       case BaseMapElement::IntAirport:
       case BaseMapElement::CivMilAirport:
       case BaseMapElement::Airfield:
-      case BaseMapElement::Glidersite:
+      case BaseMapElement::Gliderfield:
         return true;
       default:
         return false;
       }
   }
 
-QString MapConfig::getPixmapName(unsigned int typeID, bool isWinch, bool rotatable, QColor /*color*/ )
+QString MapConfig::getPixmapName(unsigned int typeID, bool isWinch, bool rotatable )
 {
   QString iconName;
 
@@ -678,7 +681,7 @@ QString MapConfig::getPixmapName(unsigned int typeID, bool isWinch, bool rotatab
     case BaseMapElement::AmbHeliport:
       iconName = "ambheliport";
       break;
-    case BaseMapElement::Glidersite:
+    case BaseMapElement::Gliderfield:
       if (isWinch)
         iconName = "glider_winch";
       else
@@ -752,6 +755,8 @@ QString MapConfig::getPixmapName(unsigned int typeID, bool isWinch, bool rotatab
       break;
 
     default:
+      qWarning() << "MapConfig::getPixmapName: No pixmap mapping found for typeId"
+                 << typeID;
       iconName = "empty";
       break;
     }
