@@ -6,13 +6,13 @@
  **
  ************************************************************************
  **
- **   Copyright (c):  2000 by Heiner Lamprecht, Florian Ehinger
- **                   2008 Axel Pauli
+ **   Copyright (c):  2000      by Heiner Lamprecht, Florian Ehinger
+ **                   2008-2011 by Axel Pauli
  **
  **   This file is distributed under the terms of the General Public
- **   Licence. See the file COPYING for more information.
+ **   License. See the file COPYING for more information.
  **
- **   $Id: radiopoint.cpp 3029 2008-09-24 20:40:17Z axel $
+ **   $Id: radiopoint.cpp 4547 2011-03-11 21:48:24Z axel $
  **
  ***********************************************************************/
 
@@ -21,9 +21,10 @@
 RadioPoint::RadioPoint(const QString& n, const QString& i,
                        const QString& g, BaseMapElement::objectType t,
                        const WGSPoint& wgsP, const QPoint& pos,
-                       const QString& f, int elev)
-  : SinglePoint(n, g, t, wgsP, pos, elev),
-    frequency(f), icao(i)
+                       const float freq, float elev,
+                       const QString country )
+  : SinglePoint( n, g, t, wgsP, pos, elev, country ),
+    frequency(freq), icao(i)
 {
 }
 
