@@ -7,12 +7,12 @@
  ************************************************************************
  **
  **   Copyright (c):  2004      by Eckhard Völlm,
- **                   2008-2009 by Axel Pauli
+ **                   2008-2011 by Axel Pauli
  **
  **   This file is distributed under the terms of the General Public
- **   Licence. See the file COPYING for more information.
+ **   License. See the file COPYING for more information.
  **
- **   $Id: reachablelist.cpp 3522 2009-09-10 21:21:38Z axel $
+ **   $Id: reachablelist.cpp 4568 2011-03-27 18:43:19Z axel $
  **
  ***********************************************************************/
 
@@ -31,12 +31,7 @@
 
 #include <math.h>
 
-#include <QString>
-#include <Qt>
-#include <QList>
-#include <QColor>
-#include <QtAlgorithms>
-#include <QDateTime>
+#include <QtCore>
 
 #include "reachablelist.h"
 #include "calculator.h"
@@ -139,7 +134,7 @@ void ReachableList::addItemsToList(enum MapContents::MapContentsListID item)
   if( item == MapContents::WaypointList )
     {
       // Waypoints have different structure treat them here
-      QList<wayPoint> &wpList = _globalMapContents->getWaypointList();
+      QList<Waypoint> &wpList = _globalMapContents->getWaypointList();
       // qDebug("Nr of Waypoints: %d", wpList.count() );
 
       for ( int i=0; i < wpList.count(); i++ )
@@ -197,12 +192,12 @@ void ReachableList::addItemsToList(enum MapContents::MapContentsListID item)
           if( item == MapContents::AirfieldList )
             {
               // Fetch data from airport list
-              site = _globalMapContents->getAirport(i);
+              site = _globalMapContents->getAirfield(i);
             }
-          else if( item == MapContents::GliderSiteList )
+          else if( item == MapContents::GliderfieldList )
             {
               // fetch data from glider site list
-              site = _globalMapContents->getGlidersite(i);
+              site = _globalMapContents->getGliderfield(i);
             }
           else if( item == MapContents::OutLandingList )
             {
@@ -219,11 +214,12 @@ void ReachableList::addItemsToList(enum MapContents::MapContentsListID item)
           QString siteName = site->getWPName();
           QString siteIcao = site->getICAO();
           QString siteDescription = site->getName();
+          QString siteCountry = site->getCountry();
           short siteType = site->getTypeID();
-          double siteFrequency = site->getFrequency().toDouble();
+          float siteFrequency = site->getFrequency();
           WGSPoint siteWgsPosition = site->getWGSPosition();
           QPoint sitePosition = site->getPosition();
-          uint siteElevation = site->getElevation();
+          float siteElevation = site->getElevation();
           QString siteComment = site->getComment();
           Runway siteRunway = site->getRunway();
 
@@ -255,6 +251,7 @@ void ReachableList::addItemsToList(enum MapContents::MapContentsListID item)
           ReachablePoint rp( siteName,
                              siteIcao,
                              siteDescription,
+                             siteCountry,
                              true,
                              siteType,
                              siteFrequency,
@@ -481,7 +478,7 @@ void ReachableList::calculateNewList()
 
   // Now add items of different type to the list
   addItemsToList(MapContents::AirfieldList);
-  addItemsToList(MapContents::GliderSiteList);
+  addItemsToList(MapContents::GliderfieldList);
   addItemsToList(MapContents::OutLandingList);
   addItemsToList(MapContents::WaypointList);
   modeAltitude = false;
@@ -546,10 +543,10 @@ void ReachableList::removeDoubles()
               //qDebug("  points are the same");
               // ok, the points are the same. Now we choose which one to remove
 
-              if ( p2.getWaypoint()->importance != p1.getWaypoint()->importance )
+              if ( p2.getWaypoint()->priority != p1.getWaypoint()->priority )
                 {
-                  // the waypoint with the lower importance will be removed
-                  if ( p2.getWaypoint()->importance > p1.getWaypoint()->importance )
+                  // the waypoint with the lower priority will be removed
+                  if ( p2.getWaypoint()->priority > p1.getWaypoint()->priority )
                     {
                       removeList.append(i);
                     }
