@@ -7,12 +7,12 @@
  ************************************************************************
  **
  **   Copyright (c):  2002      by Eggert Ehmke
- **                   2009-2010 by Axel Pauli
+ **                   2009-2011 by Axel Pauli
  **
  **   This file is distributed under the terms of the General Public
  **   License. See the file COPYING for more information.
  **
- **   $Id: settingspageairspace.cpp 4301 2010-10-07 21:28:03Z axel $
+ **   $Id: settingspageairspace.cpp 4613 2011-04-30 11:48:18Z axel $
  **
  ***********************************************************************/
 
@@ -25,13 +25,17 @@
 #include "distance.h"
 #include "generalconfig.h"
 #include "settingspageairspace.h"
+#include "mainwindow.h"
+#include "map.h"
 #include "mapdefaults.h"
-#include "mapview.h"
+#include "mapcontents.h"
 
 #ifdef INTERNET
 #include "airspacedownloaddialog.h"
 #endif
 
+extern MapContents *_globalMapContents;
+
 SettingsPageAirspace::SettingsPageAirspace(QWidget *parent) :
   QWidget(parent)
 {
@@ -44,9 +48,6 @@ SettingsPageAirspace::SettingsPageAirspace(QWidget *parent) :
   altUnit = Altitude::getUnit();
   QString unit = (altUnit == Altitude::meters) ? " m" : " ft";
 
-  m_warningsDlg = new SettingsPageAirspaceWarnings(this);
-  m_fillingDlg  = new SettingsPageAirspaceFilling(this);
-
   QGridLayout *topLayout = new QGridLayout(this);
   topLayout->setMargin(3);
 
@@ -123,27 +124,36 @@ SettingsPageAirspace::SettingsPageAirspace(QWidget *parent) :
 
   topLayout->setRowMinimumHeight( row++, 20 );
 
+  // All buttons are put into a hbox.
+  hbox = new QHBoxLayout;
+
 #ifdef INTERNET
 
-  cmdInstall = new QPushButton(tr("Install Airspace"), this);
-  topLayout->addWidget(cmdInstall, row, 0, Qt::AlignLeft);
+  cmdInstall = new QPushButton(tr("Download"), this);
+  hbox->addWidget(cmdInstall);
   connect (cmdInstall, SIGNAL(clicked()), this, SLOT(slot_installAirspace()));
 
-  cmdWarning = new QPushButton(tr("Airspace Warnings"), this);
-  topLayout->addWidget(cmdWarning, row, 1, Qt::AlignCenter);
-  connect (cmdWarning, SIGNAL(clicked()), m_warningsDlg, SLOT(show()));
-
-#else
-
-  cmdWarning = new QPushButton(tr("Airspace Warnings"), this);
-  topLayout->addWidget(cmdWarning, row, 0, Qt::AlignLeft);
-  connect (cmdWarning, SIGNAL(clicked()), m_warningsDlg, SLOT(show()));
+  hbox->addSpacing( 10 );
 
 #endif
 
-  cmdFilling = new QPushButton(tr("Airspace filling"), this);
-  topLayout->addWidget(cmdFilling, row, 2, Qt::AlignRight);
-  connect (cmdFilling, SIGNAL(clicked()), m_fillingDlg, SLOT(show()));
+  cmdLoading = new QPushButton(tr("Load"), this);
+  hbox->addWidget(cmdLoading);
+  connect (cmdLoading, SIGNAL(clicked()), this, SLOT(slot_openLoadDialog()));
+
+  hbox->addSpacing( 10 );
+
+  cmdWarning = new QPushButton(tr("Warnings"), this);
+  hbox->addWidget(cmdWarning);
+  connect (cmdWarning, SIGNAL(clicked()), this, SLOT(slot_openWarningDialog()));
+
+  hbox->addSpacing( 10 );
+
+  cmdFilling = new QPushButton(tr("Filling"), this);
+  hbox->addWidget(cmdFilling);
+  connect (cmdFilling, SIGNAL(clicked()), this, SLOT(slot_openFillDialog()));
+
+  topLayout->addLayout( hbox, row, 0, 1, 3 );
 
   row = 0;
   int col = 0;
@@ -368,7 +378,8 @@ SettingsPageAirspace::SettingsPageAirspace(QWidget *parent) :
 }
 
 SettingsPageAirspace::~SettingsPageAirspace()
-{}
+{
+}
 
 void SettingsPageAirspace::showEvent(QShowEvent *)
 {
@@ -447,9 +458,6 @@ void SettingsPageAirspace::slot_load()
   fillColorTMZ->setPalette( QPalette(conf->getFillColorTMZ()));
   fillColorLowFlight->setPalette( QPalette(conf->getFillColorLowFlight()));
   fillColorGliderSector->setPalette( QPalette(conf->getFillColorGliderSector()));
-
-  m_fillingDlg->slot_load();
-  m_warningsDlg->slot_load();
 }
 
 void SettingsPageAirspace::slot_save()
@@ -525,11 +533,7 @@ void SettingsPageAirspace::slot_save()
 
   // @AP: initiate a redraw of airspaces on the map due to color modifications.
   //      Not the best solution but it is working ;-)
-  extern MapView *_globalMapView;
-  _globalMapView->_theMap->scheduleRedraw(Map::airspaces);
-
-  m_fillingDlg->slot_save();
-  m_warningsDlg->slot_save();
+  Map::getInstance()->scheduleRedraw(Map::airspaces);
 }
 
 /**
@@ -639,7 +643,7 @@ void SettingsPageAirspace::slot_installAirspace()
   connect( dlg, SIGNAL(downloadAirspace( QString& )),
            this, SLOT(slot_startDownload( QString& )));
 
-  dlg->show();
+  dlg->setVisible( true );
 }
 
 /**
@@ -652,6 +656,31 @@ void SettingsPageAirspace::slot_startDownload( QString &url )
 
 #endif
 
+/* Called to open the airspace warning dialog. */
+void SettingsPageAirspace::slot_openFillDialog()
+{
+  SettingsPageAirspaceFilling* dlg = new SettingsPageAirspaceFilling(this);
+  dlg->setVisible( true );
+}
+
+/* Called to open the airspace warning dialog. */
+void SettingsPageAirspace::slot_openWarningDialog()
+{
+  SettingsPageAirspaceWarnings* dlg = new SettingsPageAirspaceWarnings(this);
+  dlg->setVisible( true );
+}
+
+/* Called to open the airspace loading selection dialog. */
+void SettingsPageAirspace::slot_openLoadDialog()
+{
+  SettingsPageAirspaceLoading* dlg = new SettingsPageAirspaceLoading(this);
+
+  connect( dlg, SIGNAL(airspaceFileListChanged()),
+           _globalMapContents, SLOT(slotReloadAirspaceData()) );
+
+  dlg->setVisible( true );
+}
+
 /* Called to ask is confirmation on the close is needed. */
 void SettingsPageAirspace::slot_query_close(bool& warn, QStringList& warnings)
 {
@@ -712,10 +741,6 @@ void SettingsPageAirspace::slot_query_close(bool& warn, QStringList& warnings)
     warn=true;
     warnings.append(tr("The Airspace drawing settings"));
   }
-
-  /*forward request to filling page */
-  m_fillingDlg->slot_query_close(warn, warnings);
-  m_warningsDlg->slot_query_close(warn, warnings);
 }
 
 void SettingsPageAirspace::slot_enabledToggled(bool enabled)
@@ -731,6 +756,7 @@ SettingsPageAirspaceFilling::SettingsPageAirspaceFilling(QWidget *parent) :
   QDialog(parent, Qt::WindowStaysOnTopHint)
 {
   setObjectName("SettingsPageAirspaceFilling");
+  setAttribute( Qt::WA_DeleteOnClose );
   setModal(true);
   setSizeGripEnabled(true);
   setWindowTitle(tr("Airspace fill settings"));
@@ -869,7 +895,7 @@ SettingsPageAirspaceFilling::SettingsPageAirspaceFilling(QWidget *parent) :
   connect(reset,    SIGNAL(clicked()), this, SLOT(slot_reset()));
   connect(defaults, SIGNAL(clicked()), this, SLOT(slot_defaults()));
 
-  connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
+  connect(buttonBox, SIGNAL(accepted()), this, SLOT(slot_save()));
   connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
 
   QSignalMapper* signalMapper = new QSignalMapper(this);
@@ -884,11 +910,13 @@ SettingsPageAirspaceFilling::SettingsPageAirspaceFilling(QWidget *parent) :
   signalMapper->setMapping(s4, 20);
 
   connect(signalMapper, SIGNAL(mapped(int)), this, SLOT(slot_change(int)));
+
+  slot_load();
 }
 
-
 SettingsPageAirspaceFilling::~SettingsPageAirspaceFilling()
-{}
+{
+}
 
 /**
  * Called to change the step width of the spin boxes.
@@ -947,7 +975,6 @@ void SettingsPageAirspaceFilling::slot_defaults()
   lateralInside->setValue(AS_FILL_INSIDE);
 }
 
-
 /**
  * Called to reset all spinboxes to zero
  */
@@ -984,56 +1011,19 @@ void SettingsPageAirspaceFilling::slot_save()
   conf->setAirspaceFillingLateral(Airspace::near,      lateralNear->value());
   conf->setAirspaceFillingLateral(Airspace::veryNear,  lateralVeryNear->value());
   conf->setAirspaceFillingLateral(Airspace::inside,    lateralInside->value());
+
+  // @AP: initiate a redraw of airspaces on the map due to color modifications.
+  //      Not the best solution but it is working ;-)
+  Map::getInstance()->scheduleRedraw(Map::airspaces);
+
+  accept();
 }
 
-
-void SettingsPageAirspaceFilling::slot_query_close(bool& warn, QStringList& warnings)
-{
-  /*set warn to 'true' if the data has changed. Note that we can NOT
-    just set warn equal to _changed, because that way we might erase
-    a warning flag set by another page! */
-  GeneralConfig * conf = GeneralConfig::instance();
-  bool changed=false;
-
-  changed |= conf->getAirspaceFillingEnabled() != enableFilling->isChecked();
-  changed |= conf->getAirspaceFillingVertical(Airspace::none)
-             != verticalNotNear->value();
-  changed |= conf->getAirspaceFillingVertical(Airspace::near)
-             != verticalNear->value();
-  changed |= conf->getAirspaceFillingVertical(Airspace::veryNear)
-             != verticalVeryNear->value();
-  changed |= conf->getAirspaceFillingVertical(Airspace::inside)
-             != verticalInside->value();
-  changed |= conf->getAirspaceFillingLateral(Airspace::none)
-             != lateralNotNear->value();
-  changed |= conf->getAirspaceFillingLateral(Airspace::near)
-             != lateralNear->value();
-  changed |= conf->getAirspaceFillingLateral(Airspace::veryNear)
-             != lateralVeryNear->value();
-  changed |= conf->getAirspaceFillingLateral(Airspace::inside)
-             != lateralInside->value();
-
-  if (changed)
-    {
-      warn=true;
-      warnings.append(tr("The Airspace filling settings"));
-    }
-}
-
-
-void SettingsPageAirspaceFilling::reject()
-{
-  slot_load();
-  QDialog::reject();
-}
-
-
 void SettingsPageAirspaceFilling::slot_enabledToggled(bool enabled)
 {
   separations->setEnabled(enabled);
 }
 
-
 /******************************************************************************/
 /*            Airspace Warning page                                           */
 /******************************************************************************/
@@ -1042,13 +1032,13 @@ SettingsPageAirspaceWarnings::SettingsPageAirspaceWarnings(QWidget *parent) :
   QDialog(parent, Qt::WindowStaysOnTopHint)
 {
   setObjectName("SettingsPageAirspaceWarnings");
+  setAttribute( Qt::WA_DeleteOnClose );
   setModal(true);
   setSizeGripEnabled(true);
   setWindowTitle(tr("Airspace warning settings"));
 
   // save current altitude unit. This unit must be considered during
   // storage. The internal storage is always in meters.
-
   altUnit = Altitude::getUnit();
   QString unit = (altUnit == Altitude::meters) ? " m" : " ft";
 
@@ -1166,7 +1156,7 @@ SettingsPageAirspaceWarnings::SettingsPageAirspaceWarnings(QWidget *parent) :
 
   connect(defaults, SIGNAL(clicked()), this, SLOT(slot_defaults()));
 
-  connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
+  connect(buttonBox, SIGNAL(accepted()), this, SLOT(slot_save()));
   connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
 
   QSignalMapper* signalMapper = new QSignalMapper(this);
@@ -1181,11 +1171,14 @@ SettingsPageAirspaceWarnings::SettingsPageAirspaceWarnings(QWidget *parent) :
   signalMapper->setMapping(s4, 1000);
 
   connect(signalMapper, SIGNAL(mapped(int)), this, SLOT(slot_change(int)));
+
+  slot_load();
 }
 
 
 SettingsPageAirspaceWarnings::~SettingsPageAirspaceWarnings()
-{}
+{
+}
 
 /**
  * Called to change the step width of the spin boxes.
@@ -1234,7 +1227,7 @@ void SettingsPageAirspaceWarnings::slot_load()
       belowWarnDistVN->setValue((int) rint(awd.verBelowVeryClose.getFeet()));
     }
 
-  // save loaded values for chamge control
+  // save loaded values for change control
   horiWarnDistValue = horiWarnDist->value();
   horiWarnDistVNValue = horiWarnDistVN->value();
 
@@ -1276,7 +1269,6 @@ void SettingsPageAirspaceWarnings::slot_defaults()
     }
 }
 
-
 void SettingsPageAirspaceWarnings::slot_save()
 {
   GeneralConfig * conf = GeneralConfig::instance();
@@ -1304,40 +1296,233 @@ void SettingsPageAirspaceWarnings::slot_save()
       awd.verBelowVeryClose.setFeet( belowWarnDistVN->value() );
     }
 
-  conf->setAirspaceWarningDistances(awd);
-}
+  conf->setAirspaceWarningDistances( awd );
 
-
-void SettingsPageAirspaceWarnings::slot_query_close( bool& warn, QStringList& warnings )
-{
-  /* set warn to 'true' if the data has changed. Note that we can NOT
-     just set warn equal to _changed, because that way we might erase
-     a warning flag set by another page! */
-  GeneralConfig * conf = GeneralConfig::instance();
-  bool changed=false;
-
-  changed |= conf->getAirspaceWarningEnabled() != enableWarning->isChecked();
-  changed |=  horiWarnDistValue != horiWarnDist->value();
-  changed |= horiWarnDistVNValue != horiWarnDistVN->value();
-  changed |= aboveWarnDistValue != aboveWarnDist->value();
-  changed |= aboveWarnDistVNValue != aboveWarnDistVN->value();
-  changed |= belowWarnDistValue != belowWarnDist->value();
-  changed |= belowWarnDistVNValue != belowWarnDistVN->value();
-
-  if (changed)
-    {
-      warn=true;
-      warnings.append(tr("The Airspace warning settings"));
-    }
-}
-
-void SettingsPageAirspaceWarnings::reject()
-{
-  slot_load();
-  QDialog::reject();
+  accept();
 }
 
 void SettingsPageAirspaceWarnings::slot_enabledToggled( bool enabled )
 {
   separations->setEnabled( enabled );
 }
+
+/******************************************************************************/
+/*            Airspace Loading page                                           */
+/******************************************************************************/
+
+/*
+ * Because Maemo 5 is using a special dialog design this window is declared
+ * as a tool window.
+ */
+SettingsPageAirspaceLoading::SettingsPageAirspaceLoading( QWidget *parent ) :
+  QWidget( parent )
+{
+  setObjectName("SettingsPageAirspaceLoading");
+  setAttribute( Qt::WA_DeleteOnClose );
+  setWindowFlags( Qt::Tool );
+  setWindowTitle(tr("Airspace loading settings"));
+  setWindowModality( Qt::WindowModal );
+
+  if( _globalMainWindow )
+    {
+      // Resize the window to the same size as the main window has. That will
+      // completely hide the parent window.
+      resize( _globalMainWindow->size() );
+    }
+
+  QVBoxLayout *topLayout = new QVBoxLayout( this );
+  topLayout->setSpacing(10);
+
+  fileTable = new QTableWidget( 0, 1, this );
+  fileTable->setToolTip( tr("Use check boxes to activate or deactivate file loading.") );
+  fileTable->setSelectionBehavior( QAbstractItemView::SelectRows );
+  fileTable->setShowGrid( true );
+
+  connect( fileTable, SIGNAL(cellClicked ( int, int )),
+           SLOT(slot_toggleCheckBox( int, int )) );
+
+  QHeaderView* hHeader = fileTable->horizontalHeader();
+  hHeader->setStretchLastSection( true );
+
+  QTableWidgetItem *item = new QTableWidgetItem( tr("Airspace Files") );
+  fileTable->setHorizontalHeaderItem( 0, item );
+
+  topLayout->addWidget( fileTable, 10 );
+
+  QDialogButtonBox* buttonBox = new QDialogButtonBox( QDialogButtonBox::Ok |
+                                                      QDialogButtonBox::Cancel );
+
+  connect(buttonBox, SIGNAL(accepted()), this, SLOT(slot_save()));
+  connect(buttonBox, SIGNAL(rejected()), this, SLOT(close()));
+
+  topLayout->addWidget( buttonBox );
+
+  //---------------------------------------------------------------------------
+  // Load table with openair files
+  QStringList mapDirs = GeneralConfig::instance()->getMapDirectories();
+  QStringList preselect;
+
+  for ( int i = 0; i < mapDirs.size(); ++i )
+    {
+      MapContents::addDir(preselect, mapDirs.at(i) + "/airspaces", "*.txt");
+      MapContents::addDir(preselect, mapDirs.at(i) + "/airspaces", "*.TXT");
+    }
+
+  preselect.sort();
+
+  int row = 0;
+  fileTable->setRowCount( row + 1 );
+
+  item = new QTableWidgetItem( tr("Select all"), 0 );
+  item->setFlags( Qt::ItemIsEnabled );
+  item->setCheckState( Qt::Unchecked );
+  fileTable->setItem( row, 0, item );
+  row++;
+
+  for( int i = 0; i < preselect.size(); i++ )
+    {
+      if ( preselect.at(i).endsWith( ".TXT" ) )
+        {
+          // Upper case file names are converted to lower case and renamed.
+          QFileInfo fInfo = preselect.at(i);
+          QString path    = fInfo.absolutePath();
+          QString fn      = fInfo.fileName().toLower();
+          QString newFn   = path + "/" + fn;
+          QFile::rename( preselect.at(i), newFn );
+          preselect[i] = newFn;
+        }
+
+      fileTable->setRowCount( row + 1 );
+
+      QString file = QFileInfo( preselect.at(i) ).fileName();
+      item = new QTableWidgetItem( file, row );
+      item->setFlags( Qt::ItemIsEnabled );
+      item->setCheckState( Qt::Unchecked );
+      fileTable->setItem( row, 0, item );
+      row++;
+    }
+
+  QStringList& files = GeneralConfig::instance()->getAirspaceFileList();
+
+  if( files.isEmpty() )
+    {
+      return;
+    }
+
+  if( files.at(0) == "All" )
+    {
+      // Set all items to checked, if All is contained in the list at the first
+      // position.
+      for( int i = 0; i < fileTable->rowCount(); i++ )
+        {
+          fileTable->item( i, 0 )->setCheckState( Qt::Checked );
+        }
+    }
+  else
+    {
+      // Set the All item to unchecked.
+      fileTable->item( 0, 0 )->setCheckState( Qt::Unchecked );
+
+      for( int i = 1; i < fileTable->rowCount(); i++ )
+        {
+          QTableWidgetItem* item = fileTable->item( i, 0 );
+
+          if( files.contains( item->text()) )
+            {
+              fileTable->item( i, 0 )->setCheckState( Qt::Checked );
+            }
+          else
+            {
+              fileTable->item( i, 0 )->setCheckState( Qt::Unchecked );
+            }
+        }
+    }
+}
+
+SettingsPageAirspaceLoading::~SettingsPageAirspaceLoading()
+{
+}
+
+/* Called to toggle the check box of the clicked table cell. */
+void SettingsPageAirspaceLoading::slot_toggleCheckBox( int row, int column )
+{
+  QTableWidgetItem* item = fileTable->item( row, column );
+
+  if( row > 0 && fileTable->item( 0, 0 )->checkState() == Qt::Checked )
+    {
+      // All is checked, do not changed other items
+      return;
+    }
+
+  item->setCheckState( item->checkState() == Qt::Checked ? Qt::Unchecked : Qt::Checked );
+
+  if( row == 0 && column == 0 )
+    {
+      // First entry was clicked. Change related check items.
+      if( item->checkState() == Qt::Checked )
+        {
+          // All other items are checked too
+          for( int i = fileTable->rowCount() - 1; i > 0; i-- )
+            {
+              fileTable->item( i, 0 )->setCheckState( Qt::Checked );
+            }
+        }
+    }
+}
+
+/* Called to save data to the configuration file. */
+void SettingsPageAirspaceLoading::slot_save()
+{
+  QStringList files;
+
+  if( fileTable->item( 0, 0 )->checkState() == Qt::Checked )
+    {
+      // All files are selected.
+      files << "All";
+    }
+  else
+    {
+      // Store only checked file items.
+      for( int i = 1; i < fileTable->rowCount(); i++ )
+        {
+          QTableWidgetItem* item = fileTable->item( i, 0 );
+
+          if( item->checkState() == Qt::Checked )
+            {
+              files << item->text();
+            }
+        }
+    }
+
+  QStringList oldFiles = GeneralConfig::instance()->getAirspaceFileList();
+
+  // save the new file list
+  GeneralConfig::instance()->setAirspaceFileList( files );
+
+  // Check, if file list has been modified
+  if( oldFiles.size() != files.size() )
+    {
+      // List size is different, emit signal.
+      QApplication::setOverrideCursor( QCursor(Qt::WaitCursor) );
+      emit airspaceFileListChanged();
+      QApplication::restoreOverrideCursor();
+    }
+  else
+    {
+      // The list size is equal, we have to check every single list element.
+      // Note that the lists are always sorted.
+      for( int i = 0; i < files.size(); i++ )
+        {
+          if( files.at(i) != oldFiles.at(i) )
+            {
+              // File names are different, emit signal.
+              QApplication::setOverrideCursor( QCursor(Qt::WaitCursor) );
+              emit airspaceFileListChanged();
+              QApplication::restoreOverrideCursor();
+              break;
+            }
+        }
+    }
+
+  close();
+}
