@@ -11,7 +11,7 @@
 **   This file is distributed under the terms of the General Public
 **   License. See the file COPYING for more information.
 **
-**   $Id: waypoint.cpp 4568 2011-03-27 18:43:19Z axel $
+**   $Id: waypoint.cpp 4636 2011-05-16 19:53:07Z axel $
 **
 ***********************************************************************/
 
@@ -59,7 +59,7 @@ Waypoint::Waypoint(const Waypoint& inst)
   elevation      = inst.elevation;
   frequency      = inst.frequency;
   isLandable     = inst.isLandable;
-  priority     = inst.priority;
+  priority       = inst.priority;
   taskPointIndex = inst.taskPointIndex;
   taskPointType  = inst.taskPointType;
 }
@@ -71,14 +71,16 @@ Waypoint::~Waypoint()
 
 bool Waypoint::equals( const Waypoint *second ) const
 {
-  if( second == 0 )
+  if( second == static_cast<Waypoint *>(0) )
     {
       return false;
     }
 
   if( this->name == second->name &&
+      this->type == second->type &&
       this->description == second->description &&
-      this->origP == second->origP )
+      this->origP == second->origP &&
+      this->taskPointIndex == second->taskPointIndex )
     {
       return true;
     }
@@ -89,8 +91,10 @@ bool Waypoint::equals( const Waypoint *second ) const
 bool Waypoint::operator==( const Waypoint& second ) const
 {
   if( name == second.name &&
+      type == second.type &&
       description == second.description &&
-      origP == second.origP )
+      origP == second.origP &&
+      taskPointIndex == second.taskPointIndex )
     {
       return true;
     }
